searchData={"items":[{"type":"task","title":"mix local.nerves","doc":"Check for updates to nerves_bootstrap\n\nExample:\n\n    mix local.nerves\n\nThis accepts the same command line options as `archive.install`.","ref":"Mix.Tasks.Local.Nerves.html"},{"type":"task","title":"mix nerves.bootstrap","doc":"Bootstrap Nerves tooling into the current Mix tooling\n\nThe Nerves lib contains all the tasks and tooling for setting up the\nenvironment needed to use the Nerves project. However, some of that\ntooling needs to be injected early in the build process before everything\nis compiled.\n\nThe purpose of this task is to ensure the Nerves integration is compiled\nfirst and available to be injected into the Mix tooling since Nerves.Bootstrap\nis available as an archive. (i.e. this is like having `:nerves` as a\ndependency of this archive even though archives do not allow traditional\ndependencies)\n\nIt is not intended to be run manually","ref":"Mix.Tasks.Nerves.Bootstrap.html"},{"type":"task","title":"mix nerves.new","doc":"Creates a new Nerves project\n\n    mix nerves.new PATH [--module MODULE] [--app APP] [--target TARGET] [--cookie STRING] [--no-nerves-pack]\n\nThe project will be created at PATH. The application name and module name\nwill be inferred from PATH unless `--module` or `--app` is given.\n\nAn `--app` option can be given in order to name the OTP application for the\nproject.\n\nA `--module` option can be given in order to name the modules in the\ngenerated code skeleton.\n\nA `--target` option can be given to limit support to one or more of the\n[officially Nerves\nsystems](https://hexdocs.pm/nerves/supported-targets.html).\n\nA `--cookie` options can be given to set the Erlang distribution\ncookie in `vm.args`. This defaults to a randomly generated string.\n\nGenerate a project without `nerves_pack` support by passing\n`--no-nerves-pack`.","ref":"Mix.Tasks.Nerves.New.html"},{"type":"task","title":"Examples - mix nerves.new","doc":"mix nerves.new blinky\n\nIs equivalent to:\n\n    mix nerves.new blinky --module Blinky\n\nGenerate a project that only supports Raspberry Pi 3\n\n    mix nerves.new blinky --target rpi3\n\nGenerate a project that supports Raspberry Pi 3 and Raspberry Pi Zero\n\n    mix nerves.new blinky --target rpi3 --target rpi0\n\nGenerate a project without `nerves_pack`\n\n    mix nerves.new blinky --no-nerves-pack","ref":"Mix.Tasks.Nerves.New.html#module-examples"},{"type":"extras","title":"Nerves.Bootstrap","doc":"# Nerves.Bootstrap\n\n[![CircleCI](https://circleci.com/gh/nerves-project/nerves_bootstrap.svg?style=svg)](https://circleci.com/gh/nerves-project/nerves_bootstrap)\n[![Hex.pm](https://img.shields.io/hexpm/v/nerves_bootstrap.svg)](https://hex.pm/packages/nerves_bootstrap)\n\nNerves.Bootstrap is an Elixir archive that brings Nerves support to Elixir's Mix\nbuild tool and provides a new project generator, `mix nerves.new`.\n\nWe recommend reading the [Nerves Installation\nGuide](https://hexdocs.pm/nerves/installation.html) for installing and using\nNerves. Read on for details specific to Nerves.Bootstrap.","ref":"readme.html"},{"type":"extras","title":"Installation - Nerves.Bootstrap","doc":"The first time you use Nerves and whenever you update your Elixir installation,\nrun the follow to install the official archive:\n\n```bash\nmix archive.install hex nerves_bootstrap\n```\n\nFrom then on, Nerves.Bootstrap checks for new versions and will let you know. To\nmanually upgrade either run the above line or the following:\n\n```bash\nmix local.nerves\n```\n\nIf you need to force a specific version, run:\n\n```bash\nmix archive.install hex nerves_bootstrap 1.0.1\n```","ref":"readme.html#installation"},{"type":"extras","title":"Mix tasks - Nerves.Bootstrap","doc":"This section provides a high level overview of Mix tasks provided by\nNerves.Bootstrap. For additional details, run `mix help task`.","ref":"readme.html#mix-tasks"},{"type":"extras","title":"mix nerves.new - Nerves.Bootstrap","doc":"A mix task for creating new Nerves projects.\n\n```bash\nmix nerves.new my_project\n```\n\nThe generated project will support compilation for all of the officially\nsupported Nerves devices. Just like the Elixir new project generator,\n`nerves.new` supports many options to tweak the output.\n\nGenerated projects will boot and provide an IEx prompt over the default console\nfor the device. Here's a script for creating a new project and building it for a\nRaspberry Pi 3:\n\n```bash\nmix nerves.new my_project\ncd my_project\n\n# Set MIX_TARGET to select Raspberry Pi 3-specific dependencies in the mix.exs\nexport MIX_TARGET=rpi3\n\n# Download dependencies, build firmware and write it to a MicroSD card\nmix deps.get\nmix firmware\nmix burn\n```\n\nGenerated projects include [NervesPack](https://hex.pm/packages/nerves_pack) in\ntheir dependency list. NervesPack depends on most of the Nerves-specific\nlibraries that you'll need at the beginning of your project. This includes those\nneeded for networking, firmware updates, and various helpful utilities.  If you\nwant a minimal project that does not include NervesPack, pass\n`--no-nerves-pack`:\n\n```bash\nmix nerves.new my_new_nerves_project --no-nerves-pack\n```","ref":"readme.html#mix-nerves-new"},{"type":"extras","title":"mix local.nerves - Nerves.Bootstrap","doc":"This task checks [hex.pm](https://hex.pm/packages/nerves_bootstrap) for updates\nto the `nerves_bootstrap` archive. If one exists, you'll be prompted to update.","ref":"readme.html#mix-local-nerves"},{"type":"extras","title":"Integration with your project - Nerves.Bootstrap","doc":"Nerves.Bootstrap injects Nerves-specific build tasks into the `mix` build process via\nan `Application.start/1` call in your project's `config.exs`. If you use `mix\nnerves.new`, your project will be created with these lines and no additional\nwork is needed.\n\n```elixir\n# config/config.exs\nimport Config\n\nApplication.start(:nerves_bootstrap)\n```","ref":"readme.html#integration-with-your-project"},{"type":"extras","title":"Internals - Nerves.Bootstrap","doc":"Nerves.Bootstrap uses Mix aliases to hook into Mix build steps.\n\nAliases vary based on whether you are compiling for your host or your target\ndevice. For host builds, Nerves.Bootstrap injects the following tasks to add\nsupport for downloading pre-compiled archives.\n\n```elixir\n[\n  \"deps.get\": [\"deps.get\", \"nerves.bootstrap\", \"nerves.deps.get\"],\n  \"deps.update\": [\"deps.update\", \"nerves.bootstrap\", \"nerves.deps.get\"]\n]\n```\n\nWhen `MIX_TARGET` is set, Nerves.Bootstrap injects the following additional\ntasks to support cross-compilation and firmware creation:\n\n```elixir\n[\n  \"deps.loadpaths\": [\"nerves.bootstrap\", \"nerves.loadpaths\", \"deps.loadpaths\"],\n  \"deps.compile\": [\"nerves.bootstrap\", \"nerves.loadpaths\", \"deps.compile\"],\n  # This is just helper to prevent trying to run tasks on host that were\n  # compiled for a target\n  run: [Nerves.Bootstrap.Aliases.run/1]\n]\n```\n\nNerves.Bootstrap provides only minimal code to inject the Nerves tooling. The\nmain Nerves tooling is the [`Nerves`](https://github.com/nerves-project/nerves)\nlibrary.","ref":"readme.html#internals"},{"type":"extras","title":"Local development - Nerves.Bootstrap","doc":"If you need to modify Nerves.Bootstrap, here's what you should do to get\nthe source code, build it and install your changes locally:\n\n```bash\ngit clone https://github.com/nerves-project/nerves_bootstrap.git\ncd nerves_bootstrap\nmix do deps.get, archive.build, archive.install\n```","ref":"readme.html#local-development"},{"type":"extras","title":"License - Nerves.Bootstrap","doc":"Copyright (C) 2017-22 Nerves Project Authors\n\n    Licensed under the Apache License, Version 2.0 (the \"License\");\n    you may not use this file except in compliance with the License.\n    You may obtain a copy of the License at [http://www.apache.org/licenses/LICENSE-2.0](http://www.apache.org/l>\n\n    Unless required by applicable law or agreed to in writing, software\n    distributed under the License is distributed on an \"AS IS\" BASIS,\n    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n    See the License for the specific language governing permissions and\n    limitations under the License.","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"1.13.0 - 2024-07-05 - Changelog","doc":"Adds support for Elixir 1.17 and OTP 27. This now requires\nElixir 1.13 as the minimum supported version\n\n* New project generator updates\n  * Adjust `vm.args.eex` to support Elixir 1.17 changes\n  * Synchronized to match the Elixir `mix new` generated content\n  * Removes the generated `target/0` function in favor of `Nerves.Runtime.mix_target()`\n  * Generated `mix.exs` now uses the current Elixir version in use\n    as the required version for the newly generated project\n  * Various dependency updates","ref":"changelog.html#1-13-0-2024-07-05"},{"type":"extras","title":"1.12.2 - 2024-04-24 - Changelog","doc":"* Fixes\n  * Targets documentation URL was outdated\n  * Simplify searching for SSH keys in the `nerves.new` generated config\n\n* Updates\n  * Changes to new Elixir slack URL in template README.md\n  * Adds Discord to template README.md","ref":"changelog.html#1-12-2-2024-04-24"},{"type":"extras","title":"1.12.1 - 2023-09-30 - Changelog","doc":"* Fixes\n  * Nerves.Bootstrap would fail to start in some cases where the dependencies\n    had not been fetched and Nerves.Bootstrap would try to warn about the\n    `:nerves` version requirement. This check has been moved to\n    `deps.precompile` which happens after dependencies are fetched and also\n    helps halt the build process if the `:nerves` version requirement is not","ref":"changelog.html#1-12-1-2023-09-30"},{"type":"extras","title":"1.12.0 - 2023-09-27 - Changelog","doc":"* Potentially breaking changes\n  * `:nerves >= 1.8.0` is now required to use this version of `nerves_bootstrap`.\n    If you keep up-to-date, then this won't be an issue for you.\n\n* Updates\n  * Removed legacy tasks (tooling now maintained in [`:nerves`](https://github.com/nerves-project/nerves))\n\n* New project generator updates\n  * Default to regulatory domain (`00`) for WiFi\n    * For US users, this means 5GHz won't work anymore since it's disabled in\n      `00` (NO-IR = no initiating radiation) until you update your config to\n      use `US`\n  * Bumped all Nerves systems to latest","ref":"changelog.html#1-12-0-2023-09-27"},{"type":"extras","title":"1.11.5 - 2023-07-07 - Changelog","doc":"* Updates\n  * Support Elixir 1.15/OTP 26\n\n* New project generator updates\n  * Adjust `vm.args.eex` based on Elixir version\n  * Fix typo in templates/new/config/host.exs\n  * Run formatting as part of `mix nerves.new`\n  * Adjust `:nerves_runtime` to be available on host\n  * Add `nerves_system_mangopi_mq_pro` system\n  * `:ring_logger` 0.10.0","ref":"changelog.html#1-11-5-2023-07-07"},{"type":"extras","title":"1.11.4 - 2023-03-03 - Changelog","doc":"* Updates\n  * Use Nerves v1.10.0 in new projects\n  * Default to adding `-code_path_choice strict` to new projects to skip a few\n    unnecessary path searches for archives\n  * Default to moving the clock forward in erlinit. This reduces the time jump\n    on boot for RTC-less devices.","ref":"changelog.html#1-11-4-2023-03-03"},{"type":"extras","title":"1.11.3 - 2022-11-05 - Changelog","doc":"* Updates\n  * Allow Nerves v1.9.0 to be used in new projects\n  * Use console logger by default in host mode. This is more like the default\n    Elixir configuration.","ref":"changelog.html#1-11-3-2022-11-05"},{"type":"extras","title":"1.11.2 - 2022-09-11 - Changelog","doc":"* Updates\n  * Remove references to `:build_embedded` since that option is planned for\n    removal in Elixir 1.15 and it wasn't needed.","ref":"changelog.html#1-11-2-2022-09-11"},{"type":"extras","title":"1.11.1 - 2022-07-07 - Changelog","doc":"* Fixes\n  * Fixed backwards compatibility issue with building Nerves systems with Nerves\n    1.7.x.","ref":"changelog.html#1-11-1-2022-07-07"},{"type":"extras","title":"1.11.0 - 2022-07-06 - Changelog","doc":"* Potentially breaking changes\n  * Elixir 1.11 or later is now required\n  * Move the core `mix` tooling to `:nerves`\n    * This is part of a bigger reorganization and adjustment to the bootstrap\n      tooling in order to reduce it's footprint. However, these changes have\n      been tested and are considered backwards compatible and most should not\n      see any impact from it. If you were using `Nerves.Bootstrap.Aliases`\n      module directly, you may notice adjusted aliases listed.\n\n* Enhancements\n  * Add GRiSP2 to officially supported Nerves devices\n  * Improve message when unknown target is selected\n  * Add `--no-nerves-pack` to nerves.new options doc\n\n* New project generator updates\n  * Remove `system_registry` option from generator\n  * toolshed 0.2.26\n  * shoehorn 0.9.1\n  * nerves_runtime 0.13.0\n  * ring_logger 0.8.5","ref":"changelog.html#1-11-0-2022-07-06"},{"type":"extras","title":"1.10.6 - 2022-02-23 - Changelog","doc":"* New project generator updates\n  * Update deprecated config option to MDNSLite\n  * Update references to `mix burn` in new project comments\n  * Update dependency versions to latest","ref":"changelog.html#1-10-6-2022-02-23"},{"type":"extras","title":"1.10.5 - Changelog","doc":"* New project generator updates\n  * Remove old reference to Mix.Config.","ref":"changelog.html#1-10-5"},{"type":"extras","title":"1.10.4 - Changelog","doc":"* New project generator updates\n  * Update dependency versions to latest","ref":"changelog.html#1-10-4"},{"type":"extras","title":"1.10.3 - Changelog","doc":"* New project generator updates\n  * Update dependency versions to latest\n  * Add NervesMOTD to the `iex.exs`\n  * Add more comments to commonly edited locations in the `mix.exs`","ref":"changelog.html#1-10-3"},{"type":"extras","title":"1.10.2 - Changelog","doc":"* New project generator updates\n  * Strip everything but docs with `MIX_ENV=dev`\n\n    Since most users don't use debug symbols, strip them out of the beams\n    even for dev builds. This keeps docs, though. Here's are some firmware\n    sizes to see the effect:\n\n    circuits_quickstart_unstripped.fw 43597619\n    circuits_quickstart_docs.fw 33595640\n    circuits_quickstart_stripped.fw 33016963\n\n    As you can see, this saves ~10 MB and retains docs.","ref":"changelog.html#1-10-2"},{"type":"extras","title":"1.10.1 - Changelog","doc":"* New project generator updates\n  * Add `config/host.exs` so that there's a more obvious location for host-only\n    configuration\n  * Add `rootfs_overlay/etc/iex.exs` to the list of files to format with `mix\n    format`","ref":"changelog.html#1-10-1"},{"type":"extras","title":"1.10.0 - Changelog","doc":"* New project generator updates\n  * Added `osd32mp1` to default targets in new project generator.\n    See [nerves_system_osd32mp1](https://github.com/nerves-project/nerves_system_osd32mp1) for system information.\n  * Update formatting to more closely match Elixir 1.11's new project generator\n  * Simplify the Nerves/Mix integration (now only an update to `config.exs`)\n  * Bump Nerves to `~> 1.7.0`\n  * Bump Shoehorn to `~> 0.7.0`\n  * Disable busy waiting in the BEAM by default.","ref":"changelog.html#1-10-0"},{"type":"extras","title":"1.9.0 - Changelog","doc":"* New project generator updates\n  * Bump [NervesPack to 0.4](https://hexdocs.pm/nerves_pack/changelog.html#v0-4-0)\n    which drops `:nerves_firwmare_ssh` in favor of `:nerves_ssh` and\n    `:ssh_subsystem_fwup` for access and updates.\n  * Bump Nerves to `~> 1.6.3`\n  * Bump NervesRuntime to `~> 0.11.3`\n  * Bump RingLogger to `~> 0.8.1`","ref":"changelog.html#1-9-0"},{"type":"extras","title":"1.8.1 - Changelog","doc":"* New project generator updates\n  * Update systems to latest versions.\n  * Add an example for overriding erlinit options using Mix config.","ref":"changelog.html#1-8-1"},{"type":"extras","title":"1.8.0 - Changelog","doc":"* New project generator updates\n  * Bump Nerves to 1.6 and update systems.\n  * Default to use `--nerves-pack`.\n  * Remove options for `--init-gadget`.","ref":"changelog.html#1-8-0"},{"type":"extras","title":"1.7.1 - Changelog","doc":"* Enhancements\n  * Updated Elixir 1.10 deprecated function calls.","ref":"changelog.html#1-7-1"},{"type":"extras","title":"1.7.0 - Changelog","doc":"* Enhancements\n  * Improved support for reproducible builds in new projects by setting\n    `source_date_epoch`. Existing projects can add this to the `:nerves` config.\n\n    For example:\n\n    ```elixir\n    config :nerves, source_date_epoch: \"1577467691\"\n    ```\n\n  * Added support for generating new projects using `nerves_pack` instead\n    of `nerves_init_gadget`. See [nerves_pack](https://github.com/nerves-project/nerves_pack) for more information.\n\n    For example:\n\n    ```bash\n    mix nerves.new my_app --nerves-pack\n    ```","ref":"changelog.html#1-7-0"},{"type":"extras","title":"1.6.3 - Changelog","doc":"* Enhancements\n  * Don't allow projects to be named `nerves`. Those won't work anyway.","ref":"changelog.html#1-6-3"},{"type":"extras","title":"1.6.2 - Changelog","doc":"* Enhancements\n  * Synchronize new project files to better match the versions from `mix new`","ref":"changelog.html#1-6-2"},{"type":"extras","title":"1.6.1 - Changelog","doc":"* Enhancements\n  * Added `rpi4` to default targets in new project generator.\n    See [nerves_system_rpi4](https://github.com/nerves-project/nerves_system_rpi4) for system information.\n  * Update release config to only strip beams for `:prod` firmware.\n\n* Bug fixes\n  * Fix `--cookie` in new project generator for overriding the cookie.","ref":"changelog.html#1-6-1"},{"type":"extras","title":"1.6.0 - Changelog","doc":"* Enhancements\n  * Updated new project generator to use Elixir ~> 1.9","ref":"changelog.html#1-6-0"},{"type":"extras","title":"1.5.3 - Changelog","doc":"* Bug fixes\n  * Change distillery to ~> 2.0 in the new project generator.","ref":"changelog.html#1-5-3"},{"type":"extras","title":"1.5.2 - Changelog","doc":"* Bug fixes\n  * Add distillery ~> 2.1 to the new project generator.\n  * Lock down the `nerves` dependency to ~> 1.4.5 in new projects.","ref":"changelog.html#1-5-2"},{"type":"extras","title":"1.5.1 - Changelog","doc":"* Bug fixes\n  * Compile distillery before nerves when included as an optional dependency.","ref":"changelog.html#1-5-1"},{"type":"extras","title":"1.5.0 - Changelog","doc":"* Enhancements\n  * New projects include [nerves_init_gadget](https://hex.pm/packages/nerves_init_gadget) by default.\n    If you want a minimal project that does not include `nerves_init_gadget`,\n    pass `--no-init-gadget`.","ref":"changelog.html#1-5-0"},{"type":"extras","title":"1.4.3 - Changelog","doc":"* Enhancements\n  * Create mix.exs files with `build_embedded: true` so that build products\n    aren't stored in the source tree. This helps fix a source of confusion when\n    switching targets and C/C++ build products don't get rebuilt.\n  * Improve the missing ssh key error message in config.exs","ref":"changelog.html#1-4-3"},{"type":"extras","title":"1.4.2 - Changelog","doc":"* Enhancements\n  * Added rpi3a to default supported targets list. See [nerves_system_rpi3a](https://github.com/nerves-project/nerves_system_rpi3a).\n  * Bumped the minimum versions from 1.5 to 1.6.\n  * Improved error message when trying to create new projects that support\n    Elixir ~> 1.8 while running a version that is < 1.8.\n  * Set required bootstrap archive version to ~> major.minor of the version of\n    `nerves_bootstrap` that generated the new project.","ref":"changelog.html#1-4-2"},{"type":"extras","title":"1.4.1 - Changelog","doc":"* Bug fixes\n  * Configure nerves_bootstrap to support Elixir ~> 1.7.\n    Use ~> 1.8 for new projects.","ref":"changelog.html#1-4-1"},{"type":"extras","title":"1.4.0 - Changelog","doc":"Version v1.4.0 adds support for Elixir 1.8's new built-in support for mix\ntargets. In Nerves, the `MIX_TARGET` was used to select the appropriate set of\ndependencies for a device. This lets you switch between building for different\nboards and your host. Elixir 1.8 pulls this support into `mix` and lets you\nannotate dependencies for which targets they should be used.\n\nSee the [project update guide](https://hexdocs.pm/nerves/updating-projects.html#updating-from-v1-3-x-to-v1-4-x) to learn how to migrate your project.\n\n* Enhancements\n  * New projects are generated for Elixir 1.8.\n  * Support non-RSA SSH keys in new projects.","ref":"changelog.html#1-4-0"},{"type":"extras","title":"1.3.4 - Changelog","doc":"* New project generator fixes\n  * Enable `multi_time_warp` mode by default. This fixes an issue where the\n    Erlang system clock wouldn't get updated after the clock was set.","ref":"changelog.html#1-3-4"},{"type":"extras","title":"1.3.3 - Changelog","doc":"* New project generator enhancements\n  * Update `ring_logger` to `~> 0.6`.\n  * Add `toolshed` `~> 0.2` and update `rootfs_overlay/etc/iex.exs`\n  * Enable Erlang Distribution when `Mix.env() != :prod`\n  * Remove `ev3` from default supported target list\n  * Update `bbb` system version requirement to `~> 2.0`\n  * Update all other system version requirements to `~> 1.5`","ref":"changelog.html#1-3-3"},{"type":"extras","title":"1.3.2 - Changelog","doc":"* Enhancements\n  * Updated docs for `mix nerves.new`.\n\n* Bug fixes\n  * Invoke Nerves environment when calling `deps.compile`.\n  * Display warning instead of raising when calling `mix run`.","ref":"changelog.html#1-3-2"},{"type":"extras","title":"1.3.1 - Changelog","doc":"* Enhancements\n  * Use `:dhcpd` instead of `:linklocal` for `nerves_init_gadget` defaults.","ref":"changelog.html#1-3-1"},{"type":"extras","title":"1.3.0 - Changelog","doc":"* New features\n  * Enable `heart` in the new project generator. This engages both a\n    software-based watchdog (Erlang's `heart` feature) and a hardware-based one\n    on systems that support it. If the Erlang VM becomes unresponsive, one of\n    the watchdogs will reboot the processor. See the Erlang `heart`\n    documentation for changing timeouts and adding callbacks to your\n    application.\n  * Enable `build_embedded`. This ensures that C build products are separated\n    based on target and prevents many causes of x86 build products ending up\n    on ARM targets unintentionally.","ref":"changelog.html#1-3-0"},{"type":"extras","title":"1.2.1 - Changelog","doc":"* Bug fixes\n  * Add RingLogger to all deps in new project generator.\n    This fixes an issue that causes new projects generated with `--init-gadget`\n    to crash on boot running on the host.","ref":"changelog.html#1-2-1"},{"type":"extras","title":"1.2.0 - Changelog","doc":"Add support for generating new projects with `nerves_init_gadget`.\nTo generate a new project with `nerves_init_gadget` included,\npass `--init-gadget` to `mix nerves.new`\n\nFor example:\n\n  mix nerves.new my_app --init-gadget","ref":"changelog.html#1-2-0"},{"type":"extras","title":"1.1.0 - Changelog","doc":"This release updates the new project generator to create projects that will work\nwith Elixir 1.7 and Distillery 2.0.\n\n* Enhancements\n  * Update new project generator to support `shoehorn` v0.4.\n  * Bump minimum deps to latest versions.","ref":"changelog.html#1-1-0"},{"type":"extras","title":"v1.0.1 - Changelog","doc":"* Enhancements\n  * Update new project generator to target 1.0 systems","ref":"changelog.html#v1-0-1"},{"type":"extras","title":"v1.0.0 - Changelog","doc":"* Bug Fixes\n  * Rename `provider` to `build_runner`. Fixes issues with running\n    `mix nerves.system.shell` and `mix nerves.env --info`","ref":"changelog.html#v1-0-0"},{"type":"extras","title":"v1.0.0-rc.4 - Changelog","doc":"* Updates\n  * New project generator no longer conditionally defines `application/0` in\n    `mix.exs` depending on target. It is recommended to conditionally choose\n    the main supervisors children instead.\n  * New project generator moves the dependency `shoehorn` to be included for\n    both `host` and `target` environments.","ref":"changelog.html#v1-0-0-rc-4"},{"type":"extras","title":"v1.0.0-rc.3 - Changelog","doc":"* Updates\n  * Various new project generator code format updates. Include `:runtime_tools`\n    in `:extra_applications`.\n* Bug fixes\n  * Only display Nerves environment helper text when the Nerves environment\n    is loaded. Fixes issues with running mix commands like `mix format -` that\n    require the I/O to remain clean.","ref":"changelog.html#v1-0-0-rc-3"},{"type":"extras","title":"v1.0.0-rc.2 - Changelog","doc":"* Updates\n  * Remove `build_embedded` from the mix.exs since it was unnecessary\n  * Fix update check in `mix local.nerves`\n  * Various changes to align new project generator with the one in Elixir 1.6.\n  * Add rootfs_overlay directory and populate it with an iex.exs to load the\n    nerves_runtime IEX helpers. This replaces a common manual process of doing\n    this or something similar afterwards.\n  * Add a commented out reference for enabling Erlang's heartbeat monitor","ref":"changelog.html#v1-0-0-rc-2"},{"type":"extras","title":"v1.0.0-rc.1 - Changelog","doc":"* Bug fixes\n  * Various `mix format` updates to the template\n  * Update template so that projects use v1.0.0-rc system releases so that they\n    compile\n  * Fix archive update check logic","ref":"changelog.html#v1-0-0-rc-1"},{"type":"extras","title":"v1.0.0-rc.0 - Changelog","doc":"Nerves no longer automatically compiles any `nerves_package` that is missing\nit's pre-compiled artifact. This turned out to rarely be desired and caused\nunexpectedly long compilation times when things like the Linux kernel or gcc\ngot compiled.\n\nWhen a pre-compiled artifact is missing, Nerves will now tell you what your\noptions are to resolve this. It could be retrying `mix deps.get` to download it\nagain. If you want to force compilation to happen, add a `:nerves` option for\nthe desired package in your top level project:\n\n```elixir\n  {:nerves_system_rpi0, \"~> 1.0-rc\", nerves: [compile: true]}\n```","ref":"changelog.html#v1-0-0-rc-0"},{"type":"extras","title":"v0.8.1 - Changelog","doc":"* Bug Fixes\n  * `deps.get` and `deps.update` aliases should always be added to the\n    project regardless of target.","ref":"changelog.html#v0-8-1"},{"type":"extras","title":"v0.8.0 - Changelog","doc":"The v0.7.x and earlier releases only required two aliases in your `mix.exs` to\npull in the Nerves enhancements to `mix.exs`. This releases adds more aliases.\nRather than requiring your `mix.exs` file to be updated if the Nerves alias\nhooks change in the future, we recommend updating your `mix.exs` as follows:\n\n```elixir\n  # mix.exs\n\n  def project do\n    [\n      # ...\n      aliases: [\"loadconfig\": [&bootstrap/1]],\n    ]\n  end\n\n  # Starting nerves_bootstrap pulls in the Nerves hooks to mix, but only\n  # if the MIX_TARGET environment variable is set.\n  defp bootstrap(args) do\n    Application.start(:nerves_bootstrap)\n    Mix.Task.run(\"loadconfig\", args)\n  end\n```\n\nThis release has the following changes:\n\n* Enhancements\n  * `precompile` will compile all Nerves packages instead of only the system and\n    its children.\n  * Calling `run` while `MIX_TARGET` is set will raise an exception for trying\n    to run cross compiled code on the host.\n  * `Application.start(:nerves_bootstrap)` will attempt to add aliases to the\n    mix project on the top of the stack if `MIX_TARGET` is set.","ref":"changelog.html#v0-8-0"},{"type":"extras","title":"v0.7.1 - Changelog","doc":"* Enhancements\n  * Added alias for `deps.update` to append `nerves.deps.get` to fetch\n    artifacts.","ref":"changelog.html#v0-7-1"},{"type":"extras","title":"v0.7.0 - Changelog","doc":"* Enhancements\n  * Added Mix task `nerves.deps.get`\n  * `nerves_bootstrap` will check for updates when `nerves.deps.get` is called.\n  * Added `Nerves.Bootstrap.add_aliases/1`\n    This helper function ensures that your project has the required Nerves\n    mix aliases defined and in the correct execution order. The function takes\n    the existing aliases as a keyword list and injects the required Nerves aliases.\n    You will need to update your `mix.exs` target aliases to use this version of\n    `nerves_bootstrap` like this:\n\n    ```elixir\n    defp aliases(_target) do\n      [\n        # Add custom mix aliases here\n      ]\n      |> Nerves.Bootstrap.add_aliases()\n    end\n    ```\n\n    You should also update your required dependency for nerves to\n    `{:nerves, \"~> 0.9\", runtime: false}`\n* Bug Fixes\n  * disable precompiler when calling `mix nerves.clean` to prevent having to\n    build the package so we can clean it.\n  * Fixes issue where project dependencies that contain calls to `System.get_env`\n    in their config or mix file or rebar deps that have `rebar-config.script`\n    overrides that make `os:getenv` calls were not being configured for the\n    cross compile environment.","ref":"changelog.html#v0-7-0"},{"type":"extras","title":"v0.6.4 - Changelog","doc":"* Enhancements\n  * Changed update location from Github to hex.pm\n  * Fixed compiler warning\n  * Synchronize new project template with Elixir 1.6 updates (includes formatter)","ref":"changelog.html#v0-6-4"},{"type":"extras","title":"v0.6.3 - Changelog","doc":"* Enhancements\n  * Removed unsupported systems from default targets and added x86_64.\n  * Moved to independent hex package.","ref":"changelog.html#v0-6-3"},{"type":"extras","title":"v0.6.2 - Changelog","doc":"* Enhancements\n  * [mix nerves.new] Use the new `rootfs_overlay` option\n    rather than the deprecated `rootfs_additions` option and also recommend\n    placing the relevant files in a top-level `rootfs_overlay` directory in the\n    project root rather than in `config/rootfs_additions`.\n  * [mix nerves.new] system dependencies are appended as a list so there is a\n    clear location for where system specific dependencies are added.\n  * [mix nerves.new] moved the config for bootloader above so that it is\n    configured before importing target specific configuration.","ref":"changelog.html#v0-6-2"},{"type":"extras","title":"v0.6.1 - Changelog","doc":"* Enhancements\n  * Improved error messages in `nerves.system.shell` Mix task. In particular,\n    it now reminds you to set `MIX_TARGET`.\n* Bug Fixes\n  * The `nerves.env` Mix task (used internally by Nerves) now checks that your\n    deps have been fetched before trying to load.\n  * Fix extraneous whitespace in `mix.exs` generated by `mix nerves.new`","ref":"changelog.html#v0-6-1"},{"type":"extras","title":"v0.6.0 - Changelog","doc":"* Enhancements\n  * New `nerves.system.shell` Mix task, which provides a consistent way to\n    configure a Buildroot-based Nerves system on both OSX and Linux. This\n    replaces the `nerves.shell` Mix task that was provided by the `nerves`\n    dependency, which had not been fully implemented.\n  * Add an optional `--disabled` flag to the `nerves.env` Mix task, which allows\n    the Nerves environment to be compiled and loaded in a disabled state so that\n    it doesn't try to actually cross-compile all the dependencies at load time.\n    This is primarily used so that Mix tasks like `nerves.system.shell` can run\n    on the host without having to wait for dependencies to compile when they\n    won't even be used.\n  * Related to the previous change, the `nerves.precompile` task does not try to\n    compile the toolchain and system when `Nerves.Env` is loaded in a disabled\n    state.","ref":"changelog.html#v0-6-0"},{"type":"extras","title":"v0.5.1 - Changelog","doc":"* Bug Fixes\n  * System dependencies were not being built in order when system is the parent project","ref":"changelog.html#v0-5-1"},{"type":"extras","title":"v0.5.0 - Changelog","doc":"* Enhancements\n  * Pass +Bc in vm.args to avoid accidental CTRL+C\n  * Update deps and loosen version requirements\n  * Include `bootloader` in new projects\n* Bug Fixes\n  * Choose the right compiler when parent project is a Nerves system package","ref":"changelog.html#v0-5-0"},{"type":"extras","title":"v0.4.0 - Changelog","doc":"* Enhancements\n  * nerves.new\n    * lock files are split by target\n    * Target dependencies are explicitly broken out in mix.exs through passing\n      `--target` to the generator. Defaults to declaring all officially supported\n      Nerves Targets.\n    * A default cookie is generated and placed in the vm.args. the cookie can\n      be set by passing `--cookie`","ref":"changelog.html#v0-4-0"},{"type":"extras","title":"v0.3.1 - Changelog","doc":"* Bug Fixes\n  * Added support for OTP 20: Fixes issue with RegEx producing false positives.","ref":"changelog.html#v0-3-1"},{"type":"extras","title":"v0.3.0 - Changelog","doc":"* Enhancements\n  * nerves.new\n    * defaults to Host target env\n    * includes nerves_runtime\n    * prompt to install deps and run nerves.release.init\n    * unset MIX_TARGET when generating a new project\n* Bug Fixes\n  * removed rel/.gitignore from new project generator","ref":"changelog.html#v0-3-0"},{"type":"extras","title":"v0.2.2 - Changelog","doc":"* Enhancements\n  * Added `mix local.nerves` for updating the bootstrap archive","ref":"changelog.html#v0-2-2"},{"type":"extras","title":"v0.2.1 - Changelog","doc":"* Bug Fixes\n  * update nerves dep in new project generator to 0.4.0\n* Enhancements\n  * Additional debug output when setting `NERVES_DEBUG=1`\n  * Ability to output information about the loaded Nerves env via `mix nerves.env --info`","ref":"changelog.html#v0-2-1"},{"type":"extras","title":"v0.2.0 - Changelog","doc":"* Enhancements\n  * Support for nerves_package compiler","ref":"changelog.html#v0-2-0"},{"type":"extras","title":"v0.1.4 - Changelog","doc":"* Bug Fixes\n  * Do not warn on import Supervisor.Spec\n  * Silence alias location messages unless NERVES_DEBUG=1\n* Enhancements\n  * Support for Elixir 1.3.2","ref":"changelog.html#v0-1-4"},{"type":"extras","title":"v0.1.3 - Changelog","doc":"* Enhancements\n  * Support for elixir ~> 1.3.0-rc.0","ref":"changelog.html#v0-1-3"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,49]}}